@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::debian_dist2deb;
 
-our $DATE = '2017-01-17'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2017-01-18'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -109,7 +109,7 @@ sub handle_cmd {
             for (@rows) {
                 my $v = $_->{deb_version};
                 next unless defined $v;
-                $v =~ s/-\d+$//;
+                $v =~ s/-.+$//;
                 if ($args{needs_update}) {
                     next unless version->parse($v) <  version->parse($_->{dist_version});
                 } else {
@@ -139,7 +139,7 @@ App::lcpan::Cmd::debian_dist2deb - Show Debian package name/version for a dist
 
 =head1 VERSION
 
-This document describes version 0.004 of App::lcpan::Cmd::debian_dist2deb (from Perl distribution App-lcpan-CmdBundle-debian), released on 2017-01-17.
+This document describes version 0.005 of App::lcpan::Cmd::debian_dist2deb (from Perl distribution App-lcpan-CmdBundle-debian), released on 2017-01-18.
 
 =head1 SYNOPSIS
 
